import { EventFragment } from "@/gql/graphql";
import { isTodayOrFuture } from "@/lib/date";
import { getSingularEvents, sortSingularEvents } from "@/lib/event";
import Link from "next/link";
import { EventItem } from "./EventItem";
import styles from "./upcomingEvents.module.scss";

export const UpcomingEvents = ({ events }: { events: EventFragment[] }) => {
  const upcomingSingularEvents = sortSingularEvents(
    getSingularEvents(events).filter((event) =>
      isTodayOrFuture(event.occurrence.start)
    )
  );

  return (
    <section className={styles.upcomingWrapper}>
      <h2 className="circlehead">
        <span className="circle"></span>
        <span className="circle"></span>
        <span className="circle"></span>
        Denne uka på Chateau Neuf
      </h2>
      <ul className={styles.eventList}>
        {upcomingSingularEvents.slice(0, 10).map((event) => (
          <EventItem
            key={`${event.id}-${event.occurrence.id}`}
            event={event}
            mode="singular"
            size="medium"
          />
        ))}
      </ul>
      <div className={styles.calendarLink}>
        <Link href="/arrangementer?mode=calendar">Vis kalender &rarr;</Link>
      </div>
    </section>
  );
};
