import { graphql } from "@/gql";

export type PigName =
  | "logo"
  | "music"
  | "drink"
  | "dance"
  | "point"
  | "student"
  | "listen"
  | "guard"
  | "key"
  | "chill"
  | "peek";

export const PIG_NAMES = [
  "logo",
  "music",
  "drink",
  "dance",
  "point",
  "student",
  "listen",
  "guard",
  "key",
  "chill",
  "peek",
];

export function randomElement(array: any[]): any | undefined {
  return array.length
    ? array[Math.floor(Math.random() * array.length)]
    : undefined;
}

export function unique<T>(array: any[]): any[] {
  return Array.from(array.reduce((set, item) => set.add(item), new Set()));
}

const OneLevelOfBlocksFragmentDefinition = graphql(`
  fragment OneLevelOfBlocks on StreamFieldInterface {
    id
    blockType
    field
    ... on RichTextBlock {
      rawValue
      value
    }
    ... on ImageWithTextBlock {
      image {
        ...Image
      }
      imageFormat
      text
    }
    ... on ImageSliderBlock {
      images {
        ... on ImageSliderItemBlock {
          image {
            ...Image
          }
          text
        }
      }
    }
    ... on HorizontalRuleBlock {
      color
    }
    ... on FeaturedBlock {
      title
      featuredBlockText: text
      linkText
      imagePosition
      featuredPage {
        contentType
        pageType
        url
        ... on EventPage {
          featuredImage {
            ...Image
          }
        }
        ... on NewsPage {
          featuredImage {
            ...Image
          }
        }
      }
      featuredImageOverride {
        ...Image
      }
    }
  }
`);

const BlockFragmentDefinition = graphql(`
  fragment Blocks on StreamFieldInterface {
    ... on PageSectionBlock {
      title
      backgroundColor
      body {
        ...OneLevelOfBlocks
      }
    }
    ...OneLevelOfBlocks
  }
`);

const ImageFragmentDefinition = graphql(`
  fragment Image on CustomImage {
    id
    url
    width
    height
    alt
    attribution
  }
`);
